ETL Operations
==============

The extract, validate, transform, load, and runner modules that power both the
CLI and Python API.

.. autosummary::
   :toctree: generated

   etlplus.ops.extract
   etlplus.ops.load
   etlplus.ops.run
   etlplus.ops.transform
   etlplus.ops.validate
